---
title: From colocalisation
---

## List of features

::: gentropy.dataset.l2g_features.colocalisation.EQtlColocClppMaximumFeature
::: gentropy.dataset.l2g_features.colocalisation.PQtlColocClppMaximumFeature
::: gentropy.dataset.l2g_features.colocalisation.SQtlColocClppMaximumFeature
::: gentropy.dataset.l2g_features.colocalisation.EQtlColocH4MaximumFeature
::: gentropy.dataset.l2g_features.colocalisation.PQtlColocH4MaximumFeature
::: gentropy.dataset.l2g_features.colocalisation.SQtlColocH4MaximumFeature
::: gentropy.dataset.l2g_features.colocalisation.EQtlColocClppMaximumNeighbourhoodFeature
::: gentropy.dataset.l2g_features.colocalisation.PQtlColocClppMaximumNeighbourhoodFeature
::: gentropy.dataset.l2g_features.colocalisation.SQtlColocClppMaximumNeighbourhoodFeature
::: gentropy.dataset.l2g_features.colocalisation.EQtlColocH4MaximumNeighbourhoodFeature
::: gentropy.dataset.l2g_features.colocalisation.PQtlColocH4MaximumNeighbourhoodFeature
::: gentropy.dataset.l2g_features.colocalisation.SQtlColocH4MaximumNeighbourhoodFeature

## Common logic

::: gentropy.dataset.l2g_features.colocalisation.common_colocalisation_feature_logic
::: gentropy.dataset.l2g_features.colocalisation.extend_missing_colocalisation_to_neighbourhood_genes
::: gentropy.dataset.l2g_features.colocalisation.common_neighbourhood_colocalisation_feature_logic
